| census2000 | R Documentation |
Wooldridge Source: Obtained from the United States Census Bureau by Professor Alberto Abadie of the Harvard Kennedy School of Government. Professor Abadie kindly provided the data. Data loads lazily.
data('census2000')
A data.frame with 29501 observations on 6 variables:
state: State (ICPSR code)
puma: Public Use Microdata Area
educ: educational attainment
lweekinc: log(weekly income)
exper: years workforce experience
expersq: exper^2
pages 452-453
https://www.cengage.com/cgi-wadsworth/course_products_wp.pl?fid=M20b&product_isbn_issn=9781305270107
str(census2000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.